<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'T&uuml;rk&ccedil;e [tr]',
'0_liste' => 'spip-dev@rezo.net',
'0_mainteneur' => 'admin@inceden.net',

// A
'access_interface_graphique' => 'Tam grafik aray&uuml;ze geri d&ouml;n',
'access_mode_texte' => 'Basitle&#351;tirilmi&#351; metin aray&uuml;z&uuml;n&uuml; g&ouml;ster',
'admin_debug' => 'hata ay&#305;kla',
'admin_modifier_article' => 'Bu makaleyi de&#287;i&#351;tir',
'admin_modifier_auteur' => 'Bu yazar&#305; de&#287;i&#351;tir',
'admin_modifier_breve' => 'Bu k&#305;sa haberi de&#287;i&#351;tir',
'admin_modifier_mot' => 'Bu anahtar s&ouml;zc&uuml;&#287;&uuml; de&#287;i&#351;tir',
'admin_modifier_rubrique' => 'Bu b&ouml;l&uuml;m&uuml; de&#287;i&#351;tir',
'admin_recalculer' => 'Bu sayfay&#305; yeniden olu&#351;tur',
'afficher_trad' => '&ccedil;evirileri listele',
'alerte_maj_impossible' => '<b>Dikkat&nbsp;!</b> SQL veri taban&#305;n&#305;n @version@ s&uuml;r&uuml;m&uuml;ne g&uuml;ncellenmesi imkans&#305;z. Sorun veritaban&#305; de&#287;i&#351;tirme haklar&#305;ndan kaynaklan&#305;yor olabilir, l&uuml;tfen sitenizi bar&#305;nd&#305;ran &#351;irkete ba&#351;vurunuz.',
'alerte_modif_info_concourante' => 'D&#304;KKAT: Bu bilgi ba&#351;ka bir yerde de&#287;i&#351;tirildi. G&uuml;ncel de&#287;er &nbsp;:',
'analyse_xml' => 'XML analizi',
'annuler' => '&#304;ptal et',
'antispam_champ_vide' => 'L&uuml;tfen bu alan&#305; bo&#351; b&#305;rak&#305;n&#305;z&nbsp;:',
'articles_recents' => 'En yeni makaleler',
'avis_archive_incorrect' => 'ar&#351;iv dosyas&#305; SPIP dosyas&#305; de&#287;il',
'avis_archive_invalide' => 'bu ar&#351;iv dosyas&#305; ge&ccedil;erli de&#287;il',
'avis_attention' => 'D&#304;KKAT&nbsp;!',
'avis_champ_incorrect_type_objet' => '@type@ tipindeki nesne i&ccedil;in @name@ ismi ge&ccedil;ersiz',
'avis_colonne_inexistante' => '@col@ isimli s&uuml;tun yok',
'avis_echec_syndication_01' => 'Haber payla&#351;&#305;m&#305; ba&#351;ar&#305;s&#305;z: girdi&#287;iniz sunucu &ccedil;&ouml;z&uuml;lemedi veya hi&ccedil; bir haber sunmuyor.',
'avis_echec_syndication_02' => 'Haber payla&#351;&#305;m&#305; ba&#351;ar&#305;s&#305;z: bu sitenin sunucusuna ula&#351;&#305;lamad&#305;.',
'avis_erreur' => 'Hata: a&#351;a&#287;&#305;daki a&ccedil;&#305;klamaya bak&#305;n&#305;z',
'avis_erreur_connexion' => 'Ba&#287;lant&#305; hatas&#305;',
'avis_erreur_cookie' => '&ccedil;erez sorunu',
'avis_erreur_fonction_contexte' => 'Yaz&#305;l&#305;m hatas&#305;. Bu i&#351;lev bu bi&ccedil;imde kullan&#305;lmamal&#305;.',
'avis_erreur_mysql' => 'SQL hatas&#305;',
'avis_erreur_sauvegarde' => 'Yedeklemede hata (@type@ @id_objet@) !',
'avis_erreur_visiteur' => '&Ouml;zel alana eri&#351;im sorunu',

// B
'barre_a_accent_grave' => 'A harfinin &uuml;st&uuml;ne aksan ekle (T&uuml;rk&ccedil;ede anlams&#305;z)',
'barre_aide' => 'Sayfa d&uuml;zenini zenginle&#351;tirmek i&ccedil;in tipografik k&#305;sayollar&#305; kullan&#305;n&#305;z',
'barre_e_accent_aigu' => 'E harfinin &uuml;st&uuml;ne aksan ekle (T&uuml;rk&ccedil;e\'de anlams&#305;z)',
'barre_eo' => 'T&uuml;rk&ccedil;e\'de anlams&#305;z',
'barre_eo_maj' => 'T&uuml;rk&ccedil;e\'de anlams&#305;z',
'barre_euro' => '&euro; i&#351;aretini girin',
'barre_gras' => '{{Kal&#305;n}} yaz',
'barre_guillemets' => '&laquo; T&#305;rnak &raquo; i&ccedil;ine al',
'barre_guillemets_simples' => '&#147;&#304;kinci bi&ccedil;imde t&#305;rnak&#148; i&ccedil;ine al',
'barre_intertitre' => '{{{Araba&#351;l&#305;k\'a}}} d&ouml;n&uuml;&#351;t&uuml;r',
'barre_italic' => '{Yana yat&#305;k (italik)} yaz',
'barre_lien' => '[Hipermetin ba&#287;lant&#305;s&#305;na->http://...] d&ouml;n&uuml;&#351;t&uuml;r',
'barre_lien_input' => 'L&uuml;tfen ba&#287;lant&#305;n&#305;z&#305;n adresini girin (adresi http://www.adresim.com veya bu sitede bulunan bir metnin numaras&#305; &#351;eklinde girebilirsiniz).',
'barre_note' => '[[Sayfa sonu notuna]] d&ouml;n&uuml;&#351;t&uuml;r',
'barre_paragraphe' => 'Bir paragraf olu&#351;tur',
'barre_quote' => '<quote>Bir iletiden al&#305;nt&#305; yap</quote>',
'bouton_ajouter_document' => 'Belge Ekle',
'bouton_ajouter_image' => 'Resim Ekle',
'bouton_ajouter_image_document' => 'Bir resim veya &nbsp;belge&nbsp; eklemek',
'bouton_changer' => 'De&#287;i&#351;tir',
'bouton_chercher' => 'Ara',
'bouton_choisir' => 'Se&ccedil;',
'bouton_download' => '&#304;ndir',
'bouton_enregistrer' => 'Kaydet',
'bouton_radio_desactiver_messagerie_interne' => '&#304;&ccedil; iletileri kapat',
'bouton_radio_envoi_annonces' => 'Yazar duyurular&#305;n&#305; yolla',
'bouton_radio_non_envoi_annonces' => 'Duyurular&#305; yollama',
'bouton_radio_non_envoi_liste_nouveautes' => 'Yenilikler listesini g&ouml;nderme',
'bouton_recharger_page' => 'bu sayfay&#305; yeniden y&uuml;kle',
'bouton_telecharger' => '&#304;ndir',
'bouton_valider' => 'Onayla',

// C
'cal_apresmidi' => '&ouml;&#287;leden sonra',
'cal_jour_entier' => 'tam g&uuml;n',
'cal_matin' => 'sabah',
'cal_par_jour' => 'g&uuml;nl&uuml;k takvim',
'cal_par_mois' => 'ayl&#305;k takvim',
'cal_par_semaine' => 'haftal&#305;k takvim',
'choix_couleur_interface' => 'renk',
'choix_interface' => 'aray&uuml;z se&ccedil;imi',
'colonne' => 'S&uuml;tun',
'confirm_changer_statut' => 'Dikkat, bu eleman&#305;n durumunu de&#287;i&#351;tirmek istediniz. Devam etmek istiyor musunuz ?',
'correcte' => 'do&#287;ru',

// D
'date_aujourdhui' => 'bug&uuml;n',
'date_avant_jc' => '&#304;.&Ouml;.',
'date_dans' => ' @delai@ i&ccedil;inde',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'yar&#305;n',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ @heure@',
'date_fmt_jour_mois' => '@jour@ @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => '@date@ @nomjour@',
'date_heures' => 'saat ',
'date_hier' => 'd&uuml;n',
'date_il_y_a' => '@delai@ &ouml;nce',
'date_jnum1' => '1.',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Pazar',
'date_jour_1_abbr' => 'Pzr.',
'date_jour_1_initiale' => 'g.',
'date_jour_2' => 'Pazartesi',
'date_jour_2_abbr' => 'Ptesi.',
'date_jour_2_initiale' => 'P.',
'date_jour_3' => 'Sal&#305;',
'date_jour_3_abbr' => 'Sal&#305;',
'date_jour_3_initiale' => 'S.',
'date_jour_4' => '&Ccedil;ar&#351;amba',
'date_jour_4_abbr' => '&Ccedil;ar&#351;.',
'date_jour_4_initiale' => '&Ccedil;.',
'date_jour_5' => 'Per&#351;embe',
'date_jour_5_abbr' => 'Per&#351;.',
'date_jour_5_initiale' => 'P.',
'date_jour_6' => 'Cuma',
'date_jour_6_abbr' => 'Cuma',
'date_jour_6_initiale' => 'C.',
'date_jour_7' => 'Cumartesi',
'date_jour_7_abbr' => 'Ctesi',
'date_jour_7_initiale' => 'Ct.',
'date_jours' => 'g&uuml;n',
'date_minutes' => 'dakika',
'date_mois' => 'ay',
'date_mois_1' => 'Ocak',
'date_mois_10' => 'Ekim',
'date_mois_11' => 'Kas&#305;m',
'date_mois_12' => 'Aral&#305;k',
'date_mois_2' => '&#350;ubat',
'date_mois_3' => 'Mart',
'date_mois_4' => 'Nisan',
'date_mois_5' => 'May&#305;s',
'date_mois_6' => 'Haziran',
'date_mois_7' => 'Temmuz',
'date_mois_8' => 'A&#287;ustos',
'date_mois_9' => 'Eyl&uuml;l',
'date_saison_1' => 'k&#305;&#351;',
'date_saison_2' => 'ilkbahar',
'date_saison_3' => 'yaz',
'date_saison_4' => 'sonbahar',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'hafta',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => ' y&uuml;klemeye ger&ccedil;ekten ba&#351;lamak i&ccedil;in',
'dirs_preliminaire' => '&Ouml;n bilgi : <b>Eri&#351;im haklar&#305;n&#305; ayarlay&#305;n&#305;z</b>',
'dirs_probleme_droits' => 'Eri&#351;im haklar&#305; sorunu ',
'dirs_repertoires_absents' => '<p><b>&#350;u dizinler bulunamad&#305;&nbsp;: </b></p><ul>@bad_dirs@</ul> </b>
  <p>B&uuml;y&uuml;k k&uuml;&ccedil;&uuml;k harf hatas&#305;na ba&#287;l&#305; olabilir.
  Dizinlerin k&uuml;&ccedil;&uuml;k b&uuml;y&uuml;k harflerle yaz&#305;l&#305;&#351;lar&#305;n&#305;n yukar&#305;da g&ouml;sterilenlerle uyu&#351;tu&#287;unu kontrol edin;  e&#287;er uyu&#351;muyorsa FTP program&#305;n&#305;zla dizin isimlerini d&uuml;zeltin.</p>
  <p>Bu i&#351;lemi yapt&#305;&#287;&#305;n&#305;zda ',
'dirs_repertoires_suivants' => '<p><b>A&#351;a&#287;&#305;daki dizinlere yazma izni yoktur&nbsp;: </b></p><ul>@bad_dirs@.</ul> 
  <p>Bu sorunu &ccedil;&ouml;zmek i&ccedil;in FTP program&#305;n&#305;zla her bir dizine eri&#351;im haklar&#305;n&#305; d&uuml;zenleyin. Bu yordam, kurulum kitap&ccedil;&#305;&#287;&#305;nda detayl&#305; bi&ccedil;imde a&ccedil;&#305;klanm&#305;&#351;t&#305;r./p> 
  <p>Bu i&#351;lemi yapt&#305;&#287;&#305;n&#305;zda ',
'double_occurrence' => '&Ccedil;ift tekrar ', # MODIF

// E
'en_cours' => 'i&#351;lenmekte',
'entree_dimensions' => 'Boyutlar&nbsp;:',
'entree_titre_document' => 'Belge ba&#351;l&#305;&#287;&#305;&nbsp;:',
'entree_titre_image' => 'Resim ba&#351;l&#305;&#287;&#305;&nbsp;:',
'envoi_via_le_site' => 'Site &uuml;zerinden g&ouml;nder',
'erreur' => 'Hata',
'erreur_balise_non_fermee' => 'son etiket kapat&#305;lmam&#305;&#351; :',
'erreur_texte' => 'hata(lar)',
'etape' => 'A&#351;ama',

// F
'fichier_introuvable' => '@fichier@ dosyas&#305; bulunamad&#305;',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Zaten kay&#305;tl&#305;s&#305;n&#305;z.',
'form_email_non_valide' => 'E-posta adresiniz ge&ccedil;ersiz.',
'form_forum_access_refuse' => 'Art&#305;k bu siteye eri&#351;im izniniz yok.',
'form_forum_bonjour' => 'Merhaba @nom@,',
'form_forum_email_deja_enregistre' => 'Bu e-posta adresi zaten kay&#305;tl&#305;, kullanmakta oldu&#287;unuz &#351;ifrenizi kullanmaya devam edebilirsiniz.',
'form_forum_identifiant_mail' => 'Yeni tan&#305;mlay&#305;c&#305;n&#305;z e-posta yoluyla g&ouml;nderildi.',
'form_forum_identifiants' => 'Ki&#351;isel tan&#305;mlay&#305;c&#305;lar',
'form_forum_indiquer_nom_email' => 'Buraya isminizi ve e-posta adresinizi giriniz. Yeni tan&#305;mlay&#305;c&#305;n&#305;z size bir e-posta ile hemen g&ouml;nderilecektir.',
'form_forum_login' => 'kullan&#305;c&#305; ismi :',
'form_forum_message_auto' => '(bu otomatik bir iletidir)',
'form_forum_pass' => '&#351;ifre :',
'form_forum_probleme_mail' => 'E-posta sorunu&nbsp;: tan&#305;mlay&#305;c&#305; g&ouml;nderilemiyor.',
'form_forum_voici1' => '"@nom_site_spip@" (@adresse_site@) site ya&#351;am&#305;na kat&#305;labilmek i&ccedil;in tan&#305;mlay&#305;c&#305;lar&#305;n&#305;z :',
'form_forum_voici2' => '"@nom_site_spip@" (@adresse_login@) sitesinde makale yay&#305;nlayabilmeniz i&ccedil;in gereken kimlik bilgileriniz :',
'form_indiquer_email' => 'L&uuml;tfen e-posta adresinizi belirtiniz.',
'form_indiquer_nom' => 'L&uuml;tfen isminizi belirtiniz.',
'form_indiquer_nom_site' => 'L&uuml;tfen sitenizin ismini belirtiniz.',
'form_pet_adresse_site' => 'Sitenizin adresi',
'form_pet_aucune_signature' => 'Bu koda kar&#351;&#305;l&#305;k hi&ccedil; bir imza yok...',
'form_pet_confirmation' => 'L&uuml;tfen imzan&#305;z&#305; onaylay&#305;n&#305;z :',
'form_pet_deja_enregistre' => 'Bu site zaten kay&#305;tl&#305;',
'form_pet_deja_signe' => 'Bu metni zaten imzalam&#305;&#351;s&#305;n&#305;z.',
'form_pet_envoi_mail_confirmation' => '&#350;u anda @email@ adresine bir do&#287;rulama e-postas&#305; g&ouml;nderildi. &#304;mzan&#305;z&#305; do&#287;rulamak i&ccedil;in bu iletide belirtilen web adresini ziyaret etmelisiniz.',
'form_pet_mail_confirmation' => 'Merhaba,

Bir dilek&ccedil;e imzalamak istediniz :
@titre@.

Ve &#351;u bilgileri girdiniz :
    &#304;sim: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@


&Ouml;NEML&#304; ...
&#304;mzan&#305;z&#305; onaylamak i&ccedil;in a&#351;a&#287;&#305;daki adrese ba&#287;lanman&#305;z yeterli
 (aksi halde iste&#287;iniz
reddedilecektir) :

    @url@


Kat&#305;l&#305;m&#305;n&#305;z i&ccedil;in te&#351;ekk&uuml;rler
',
'form_pet_message_commentaire' => 'Bir ileti, bir yorum&nbsp;?',
'form_pet_nom_site2' => 'Sitenizin ismi',
'form_pet_probleme_liens' => 'L&uuml;tfen iletinizi hipermetin ba&#287;lar&#305;n&#305; silerek tekrar giriniz',
'form_pet_probleme_technique' => 'Teknik bir sorun var, imzalar ge&ccedil;ici olarak iptal edildi.',
'form_pet_signature_pasprise' => '&#304;mzan&#305;z dikkate al&#305;nmad&#305;.',
'form_pet_signature_validee' => '&#304;mzan&#305;z onayland&#305;. Te&#351;ekk&uuml;rler&nbsp;!',
'form_pet_site_deja_enregistre' => 'Bu site zaten kay&#305;tl&#305;',
'form_pet_url_invalide' => 'Belirtti&#287;iniz Url ge&ccedil;erli de&#287;il.',
'form_pet_votre_email' => 'E-posta adresiniz',
'form_pet_votre_nom' => '&#304;sminiz veya takma isminiz',
'form_pet_votre_site' => 'E&#287;er bir siteniz varsa bunu a&#351;a&#287;&#305;da belirtebilirsiniz',
'form_prop_confirmer_envoi' => 'G&ouml;nderiyi onayla',
'form_prop_description' => 'Tan&#305;m / Yorum',
'form_prop_enregistre' => '&Ouml;neriniz kaydedildi, sitenin sorumlular&#305; taraf&#305;ndan onayland&#305;ktan sonra &ccedil;evrimi&ccedil;i yay&#305;nlanacak.',
'form_prop_envoyer' => 'Bir ileti g&ouml;nder',
'form_prop_indiquer_email' => 'L&uuml;tfen ge&ccedil;erli bir e-posta adresi belirtiniz',
'form_prop_indiquer_nom_site' => 'Sitenin ismini giriniz.',
'form_prop_indiquer_sujet' => 'Bir konu belirtiniz',
'form_prop_message_envoye' => '&#304;leti g&ouml;nderildi',
'form_prop_nom_site' => 'Sitenin ismi',
'form_prop_non_enregistre' => '&Ouml;neriniz kaydedilmedi.',
'form_prop_sujet' => 'Konu',
'form_prop_url_site' => 'Sitenin Url adresi',
'forum_acces_refuse' => 'Art&#305;k bu forumlara eri&#351;iminiz yok.',
'forum_attention_dix_caracteres' => '<b>Dikkat&nbsp;!</b> iletiniz on karakterden k&#305;sa.',
'forum_attention_trois_caracteres' => '<b>Dikkat&nbsp;!</b> ba&#351;l&#305;&#287;&#305;n&#305;z &uuml;&ccedil; karakterden k&#305;sa.',
'forum_attention_trop_caracteres' => '<b>Dikkat&nbsp;!</b> mesaj&#305;n&#305;z &ccedil;ok uzun (@compte@ caract&egrave;res)&nbsp;: kaydedilebilmesi i&ccedil;in @max@ karakteri a&#351;mamal&#305;.',
'forum_avez_selectionne' => '&#350;unu se&ccedil;tiniz&nbsp;:',
'forum_cliquer_retour' => 'Devam etmek i&ccedil;in <a href=\'@retour_forum@\'>buraya t&#305;klay&#305;n&#305;z</a>.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Bu forum &ouml;nceden onayla y&ouml;netilmektedir&nbsp;: katk&#305;n&#305;z ancak bir y&ouml;netici taraf&#305;ndan onayland&#305;ktan sonra g&ouml;r&uuml;lebilecektir.',
'forum_lien_hyper' => '<b>Hipermetin ba&#287;&#305;</b> (se&ccedil;imlik)',
'forum_message_definitif' => '&#304;letinin son hali : siteye g&ouml;nder',
'forum_message_trop_long' => '&#304;letiniz &ccedil;ok uzun. Bir ileti en fazla 20000 karakter i&ccedil;erebilir.',
'forum_ne_repondez_pas' => 'Bu e-postaya yan&#305;t vermeyin, yan&#305;t i&ccedil;in forumu kullan&#305;n :',
'forum_non_inscrit' => 'Kay&#305;tl&#305; de&#287;ilsiniz veya adresiniz veya &#351;ifreniz hatal&#305;.',
'forum_page_url' => '(E&#287;er mesaj&#305;n&#305;z Web\'de yay&#305;nlanan bir makaleye, ya da daha fazla bilgi i&ccedil;eren bir sayfaya at&#305;fta bulunuyorsa, l&uuml;tfen buraya sayfan&#305;n ba&#351;l&#305;&#287;&#305;n&#305; ve URL adresini belirtiniz.)',
'forum_par_auteur' => 'yazan @auteur@ ',
'forum_poste_par' => 'Makalenize @parauteur@ ileti g&ouml;nderildi.',
'forum_probleme_database' => 'Veritaban&#305; sorunu, mesaj&#305;n&#305;z kaydedilemedi.',
'forum_qui_etes_vous' => '<b>Sizi tan&#305;yal&#305;m ?</b> (se&ccedil;imlik)',
'forum_texte' => '&#304;letinizin metni :',
'forum_titre' => 'Ba&#351;l&#305;k :',
'forum_titre_erreur' => 'Hata...',
'forum_url' => 'URL :',
'forum_valider' => 'Bu se&ccedil;imi onayla',
'forum_voir_avant' => 'G&ouml;ndermeden &ouml;nce iletiyi g&ouml;ster',
'forum_votre_email' => 'E-posta adresiniz :',
'forum_votre_nom' => '&#304;sminiz (veya takma isminiz) :',
'forum_vous_enregistrer' => 'Bu foruma kat&#305;lmak i&ccedil;in, 
&ouml;nce kaydolman&#305;z gerekmektedir.
 L&uuml;tfen a&#351;a&#287;&#305;ya size verilmi&#351; olan tan&#305;mlay&#305;c&#305;y&#305; giriniz.
 E&#287;er kaydolmam&#305;&#351;san&#305;z, yapman&#305;z gereken',
'forum_vous_inscrire' => '&ouml;nce kaydolmakt&#305;r.</a>',

// I
'ical_texte_rss_articles' => 'Makalelerin &laquo;backend&raquo; dosyas&#305; &#351;u adrestedir:',
'ical_texte_rss_articles2' => 'Sitenin her bir b&ouml;l&uuml;m&uuml;n&uuml;n makaleleri i&ccedil;in &laquo;backend&raquo; dosyalar&#305; edinebilirsiniz :',
'ical_texte_rss_breves' => 'Ayr&#305;ca site haberlerini i&ccedil;eren bir dosya mevcuttur. Bir b&ouml;l&uuml;m numaras&#305; belirterek, sadece bu b&ouml;l&uuml;m&uuml;n haberlerini elde edebilirsiniz.',
'icone_a_suivre' => '&#304;zlenecek',
'icone_admin_site' => 'Site y&ouml;netimi',
'icone_agenda' => 'Ajanda',
'icone_aide_ligne' => 'Yard&#305;m',
'icone_articles' => 'Makaleler',
'icone_auteurs' => 'Yazarlar',
'icone_breves' => 'K&#305;sa haberler',
'icone_brouteur' => 'H&#305;zl&#305; gezinti',
'icone_configuration_site' => 'Yap&#305;land&#305;rma',
'icone_configurer_site' => 'Sitenizi yap&#305;land&#305;r&#305;n',
'icone_creer_nouvel_auteur' => 'Yeni bir yazar olu&#351;tur',
'icone_creer_rubrique' => 'B&ouml;l&uuml;m olu&#351;tur',
'icone_creer_sous_rubrique' => 'Alt-b&ouml;l&uuml;m olu&#351;tur',
'icone_deconnecter' => '&Ccedil;&#305;k&#305;&#351;',
'icone_discussions' => 'Tart&#305;&#351;malar',
'icone_doc_rubrique' => 'B&ouml;l&uuml;m belgeleri',
'icone_ecrire_article' => 'Yeni bir makale yaz',
'icone_edition_site' => 'Yay&#305;n',
'icone_forum_administrateur' => 'Y&ouml;neticiler forumu',
'icone_forum_suivi' => 'Forum takibi',
'icone_gestion_langues' => 'Dillerin y&ouml;netimi',
'icone_informations_personnelles' => 'Ki&#351;isel bilgiler',
'icone_interface_complet' => 'T&uuml;m aray&uuml;z',
'icone_interface_simple' => 'Basit aray&uuml;z',
'icone_maintenance_site' => 'Site bak&#305;m&#305;',
'icone_messagerie_personnelle' => 'Ki&#351;isel iletiler',
'icone_mots_cles' => 'Anahtar s&ouml;zc&uuml;kler',
'icone_nouvelle_breve' => 'Yeni bir k&#305;sa haber yaz',
'icone_repartition_actuelle' => 'Mevcut da&#287;&#305;l&#305;m&#305; g&ouml;ster',
'icone_repartition_debut' => 'Da&#287;&#305;l&#305;m&#305; en ba&#351;&#305;ndan itibaren g&ouml;ster',
'icone_repartition_visites' => 'Ziyaretlerin da&#287;&#305;l&#305;m&#305;',
'icone_rubriques' => 'B&ouml;l&uuml;mler',
'icone_sauver_site' => 'Siteyi yedekle',
'icone_site_entier' => 'T&uuml;m site',
'icone_sites_references' => '&Ouml;nerilen siteler',
'icone_statistiques' => 'Site istatistikleri',
'icone_statistiques_visites' => '&#304;statistikler',
'icone_suivi_activite' => 'Site ya&#351;am&#305;n&#305; izle',
'icone_suivi_actualite' => 'Site&nbsp;geli&#351;imi',
'icone_suivi_forums' => 'Forumlar&#305; izle / Y&ouml;net',
'icone_suivi_pettions' => 'Dilek&ccedil;eleri izle / Y&ouml;net',
'icone_suivi_revisions' => 'Makale de&#287;i&#351;iklikleri',
'icone_supprimer_document' => 'Bu belgeyi sil',
'icone_supprimer_image' => 'Bu resmi sil',
'icone_supprimer_message' => 'Bu iletiyi sil',
'icone_tous_articles' => 'T&uuml;m makaleleriniz',
'icone_tous_auteur' => 'T&uuml;m yazarlar',
'icone_valider_message' => '&#304;letiyi onayla',
'icone_visiter_site' => 'Ziyaret et',
'icone_voir_en_ligne' => '&Ccedil;evrimi&ccedil;i g&ouml;ster',
'image_tourner_180' => '180&deg; d&ouml;nd&uuml;r',
'image_tourner_droite' => '90&deg; sa&#287;a d&ouml;nd&uuml;r',
'image_tourner_gauche' => '90&deg; sola d&ouml;nd&uuml;r',
'img_indisponible' => 'resim mevcut de&#287;il',
'impossible' => 'olanaks&#305;z',
'info_a_suivre' => '&#304;ZLENECEK&nbsp;&raquo;',
'info_a_valider' => '[onaylanacak]',
'info_acces_interdit' => 'Eri&#351;im yasak',
'info_acces_refuse' => 'Eri&#351;im reddedildi',
'info_action' => 'Eylem : @action@',
'info_administrer_rubriques' => 'Bu b&ouml;l&uuml;m&uuml; ve alt-b&ouml;l&uuml;mleri y&ouml;netebilirsiniz',
'info_adresse_non_indiquee' => 'Denenecek bir adres belirtmediniz&nbsp;!',
'info_aide' => 'YARDIM :',
'info_ajouter_mot' => 'Bu s&ouml;zc&uuml;&#287;&uuml; ekle',
'info_annonce' => 'DUYURU',
'info_annonces_generales' => 'Genel duyurular&nbsp;:',
'info_article_propose' => '&Ouml;nerilen makale',
'info_article_publie' => 'Yay&#305;nlanan makale',
'info_article_redaction' => 'Yaz&#305;lmakta olan makale',
'info_article_refuse' => 'Reddedilen makale',
'info_article_supprime' => 'Silinen makale',
'info_articles' => 'Makaleler',
'info_articles_a_valider' => 'Onaylanacak makaleler',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => '&Ouml;nerilen makaleler',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'yazar(lar)&nbsp;:',
'info_authentification_ftp' => 'Onay (FTP ile)',
'info_bloquer_lien' => 'bu ba&#287;lant&#305;y&#305; engelle',
'info_breves_02' => 'K&#305;sa haberler',
'info_breves_2' => 'k&#305;sa haberler',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Onaylanacak k&#305;sa haberler',
'info_connexion_refusee' => 'Ba&#287;lant&#305; reddedildi',
'info_contact_developpeur' => 'L&uuml;tfen bir program geli&#351;tirici ile temasa ge&ccedil;iniz.',
'info_contenance' => 'Site i&ccedil;eri&#287;i&nbsp;:',
'info_contribution' => 'Forum katk&#305;lar&#305;',
'info_copyright' => '@spip@, @lien_gpl@ GPL lisans&#305; ile da&#287;&#305;t&#305;lan serbest bir yaz&#305;l&#305;md&#305;r.',
'info_copyright_doc' => 'Ayr&#305;nt&#305;l&#305; bilgi i&ccedil;in, bkz.  <a href="@spipnet@">http://www.spip.net/fr</a>.',
'info_copyright_gpl' => 'GPL lisans&#305; alt&#305;nda',
'info_cours_edition' => 'Yaz&#305;lmakta olan makaleleriniz',
'info_creer_repertoire' => '&#350;u isimde bir dosya veya dizin olu&#351;turunuz&nbsp;:',
'info_creer_repertoire_2' => '<b>@repertoire@</b> alt-dizini i&ccedil;erisinde, daha sonra&nbsp;:',
'info_creer_vignette' => 'otomatik ikon olu&#351;turma',
'info_deplier' => 'A&ccedil;&#305;l&#305;p sergilenmesi',
'info_descriptif_nombre' => 'tan&#305;mlay&#305;c&#305;(lar) :',
'info_description' => 'Tan&#305;mlama&nbsp;:',
'info_description_2' => 'Tan&#305;mlama&nbsp;:',
'info_dimension' => 'Boyutlar&nbsp;:',
'info_document' => 'Belge',
'info_document_indisponible' => 'Bu belge uygun (bo&#351;ta) de&#287;il',
'info_documents' => 'Belge',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP site kat&#305;l&#305;mc&#305;lar&#305; aras&#305;nda ileti al&#305;&#351;veri&#351;i
                           ve &ouml;zel sohbet forumlar&#305; olu&#351;turma olana&#287;&#305; verir.
                           Bu i&#351;levi &ccedil;al&#305;&#351;t&#305;rabilir veya durdurabilirsiniz.',
'info_ecire_message_prive' => '&Ouml;zel bir ileti yaz',
'info_email_invalide' => 'Ge&ccedil;ersiz e-posta adresi.',
'info_en_cours_validation' => 'Yaz&#305;lmakta olan makaleleriniz',
'info_en_ligne' => '&#350;u anda &ccedil;evrimi&ccedil;i&nbsp;:',
'info_envoyer_message_prive' => 'Bu yazara &ouml;zel bir ileti g&ouml;nder',
'info_erreur_requete' => 'Aramada hata :',
'info_erreur_squelette2' => 'Hi&ccedil;bir @fichier@ iskeleti m&uuml;sait de&#287;il...',
'info_erreur_systeme' => 'Sistem hatas&#305; (hata no @errsys@)',
'info_erreur_systeme2' => 'Sabit disk dolu olabilir veya veritaban&#305; hasar g&ouml;rm&uuml;&#351; olabilir.  <br />
 <font color=\'red\'>Veritaban&#305;n&#305; <a href=\'@script@\'>onarmay&#305; deneyiniz </a>,
 veya sitenizi bar&#305;nd&#305;ran firmay&#305; aray&#305;n&#305;z.</font>',
'info_fini' => 'Bitti !',
'info_format_image' => '&#304;kon yaratmak i&ccedil;in kullan&#305;labilecek resim formatlar&#305;&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'tan&#305;ms&#305;z format',
'info_grand_ecran' => 'B&uuml;y&uuml;k ekran',
'info_image_aide' => 'YARDIM',
'info_image_process_titre' => '&#304;kon olu&#351;turma y&ouml;ntemleri',
'info_impossible_lire_page' => '<b>Hata !</b> Sayfa vekil (proxy) &uuml;zerinden <tt><html>@test_proxy@</html></tt> okunam&#305;yor  <tt>',
'info_inclusion_directe' => 'Direkt ekleme&nbsp;:',
'info_inclusion_vignette' => '&#304;kon ekleme&nbsp;:',
'info_installation_systeme_publication' => 'Yay&#305;n sistemi kurulumu...',
'info_installer_documents' => '@upload@ dizininde bulunan t&uuml;m belgeleri otomatik olarak kurabilirsiniz. ',
'info_installer_ftp' => 'Y&ouml;netici olarak (FTP ile) @upload@ dizinine dosya g&ouml;nderip sonra onlar&#305; buradan direkt olarak se&ccedil;ebilirsiniz. ',
'info_installer_images' => 'JPEG, GIF ve PNG format&#305;nda resimler y&uuml;kleyebilirsiniz.',
'info_installer_images_dossier' => 'Buradan se&ccedil;im yapabilmek i&ccedil;in @upload@ dizinine resim y&uuml;kleyiniz. ',
'info_installer_tous_documents' => 'T&uuml;m belgeleri kur',
'info_interface_complete' => 'Tam aray&uuml;z',
'info_interface_simple' => 'Basit aray&uuml;z',
'info_joindre_document_article' => 'Bu makaleye ekleyebilece&#287;iniz belgeler ',
'info_joindre_document_rubrique' => 'Bu b&ouml;l&uuml;me ekleyebilece&#287;iniz belgeler ',
'info_joindre_documents_article' => 'Makalenize ekleyebilece&#287;iniz belgeler &nbsp;:',
'info_l_article' => 'makale',
'info_la_breve' => 'k&#305;sa haber',
'info_la_rubrique' => 'b&ouml;l&uuml;m',
'info_langue_principale' => 'Sitenin ana dili',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ piksel',
'info_les_auteurs_1' => 'yazan @les_auteurs@ ',
'info_logo_format_interdit' => 'Sadece @formats@ format&#305;ndaki logolar kullan&#305;labilir.',
'info_logo_max_poids' => 'Logolar @maxi@ dan daha k&uuml;&ccedil;&uuml;k olmal&#305;d&#305;r (bu dosyan&#305;n boyutu  @actuel@).',
'info_logo_max_taille' => 'Logolar @maxi@ dan daha k&uuml;&ccedil;&uuml;k olmal&#305;d&#305;r (bu dosyan&#305;n boyutu  @actuel@).',
'info_mail_fournisseur' => 'isminiz@hizmet_veren_firma.com',
'info_message_2' => '&#304;LET&#304;',
'info_message_supprime' => '&#304;LET&#304; S&#304;L&#304;ND&#304;',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => '&Ccedil;evrimi&ccedil;i yay&#305;n tarihi&nbsp;:',
'info_modification_parametres_securite' => 'g&uuml;venlik parametreleri de&#287;i&#351;ikli&#287;i',
'info_mois_courant' => 'Ay i&ccedil;inde :',
'info_mot_cle_ajoute' => '&#350;u anahtar s&ouml;zc&uuml;k eklendi > ',
'info_multi_herit' => 'Varsay&#305;lan dil :',
'info_multi_langues_soulignees' => '<u>Alt&#305; &ccedil;izili dillerin</u> aray&uuml;zde t&uuml;m metinlerin &ccedil;evirileri bulunmaktad&#305;r. Bu dilleri se&ccedil;erseniz, kamu sitesinin bir &ccedil;ok eleman&#305; (tarihler, formlar) otomatik olarak &ccedil;evrilecektir. Alt&#305; &ccedil;izili olmayan diller i&ccedil;in ise bu elemanlar sitenin ba&#351;l&#305;ca dilinde g&ouml;r&uuml;nt&uuml;lenecektir.',
'info_multilinguisme' => '&Ccedil;ok dillilik',
'info_nom_non_utilisateurs_connectes' => 'Ba&#287;l&#305; kullan&#305;c&#305;lar listesinde isminiz g&ouml;r&uuml;nm&uuml;yor.',
'info_nom_utilisateurs_connectes' => 'Ba&#287;l&#305; kullan&#305;c&#305;lar listesinde isminiz g&ouml;r&uuml;n&uuml;yor.',
'info_nombre_en_ligne' => '&#350;u anda &ccedil;evrimi&ccedil;i :',
'info_non_resultat' => '"@cherche_mot@" i&ccedil;in hi&ccedil; sonu&ccedil; yok',
'info_non_utilisation_messagerie' => 'Bu sitenin i&ccedil; ileti sistemini kullanm&#305;yorsunuz.',
'info_nouveau_message' => 'YEN&#304; B&#304;R &#304;LET&#304;N&#304;Z VAR',
'info_nouveaux_messages' => '@total_messages@ YEN&#304; MESAJINIZ VAR',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Bu bilgi zorunludur.',
'info_panne_site_syndique' => 'Payla&#351;&#305;ml&#305; sitede ar&#305;za var',
'info_pense_bete' => 'HATIRLATMA',
'info_petit_ecran' => 'K&uuml;&ccedil;&uuml;k ekran',
'info_petition_close' => 'Dilek&ccedil;e kapand&#305;',
'info_pixels' => 'Piksel',
'info_plusieurs_mots_trouves' => ' "@cherche_mot@" i&ccedil;in bir&ccedil;ok anahtar s&ouml;zc&uuml;k bulundu',
'info_popularite_5' => 'Pop&uuml;lerlik  ',
'info_portfolio' => 'Portf&ouml;y',
'info_portfolio_automatique' => 'Otomatik portf&ouml;y&nbsp;:',
'info_premier_resultat' => '[Toplam @total@ dan @debut_limit@ ilk sonu&ccedil;]',
'info_premier_resultat_sur' => '[@debut_limit@ ilk sonu&ccedil; / @total@ sonu&ccedil;]',
'info_probleme_grave' => 'sorun',
'info_propose_1' => '[@nom_site_spip@] &Ouml;neriyor : @titre@',
'info_propose_2' => '&Ouml;nerilen makale
---------------',
'info_propose_3' => '"@titre@" makalesi yay&#305;nlanmak &uuml;zere &ouml;nerildi.',
'info_propose_4' => 'L&uuml;tfen inceleyiniz ve g&ouml;r&uuml;&#351;&uuml;n&uuml;z&uuml; belirtiniz',
'info_propose_5' => 'ba&#287;l&#305; olan forumda. Forumun adresi:',
'info_publie_01' => '"@titre@" makalesi @connect_nom@ taraf&#305;ndan onayland&#305;.',
'info_publie_1' => '[@nom_site_spip@] YAYINLANDI : @titre@',
'info_publie_2' => 'Yay&#305;nlanan makale
-----------------',
'info_rechercher' => 'Ara',
'info_rechercher_02' => 'Ara&nbsp;:',
'info_remplacer_vignette' => 'Varsay&#305;lan etiketi ki&#351;iselle&#351;tirilmi&#351; bir logo ile de&#287;i&#351;tir&nbsp;:',
'info_retablir_lien' => 'Bu ba&#287;lant&#305;y&#305; tekrar kur',
'info_retirer_mot' => 'Bu anahtar s&ouml;zc&uuml;&#287;&uuml; geri al',
'info_retirer_mots' => 'T&uuml;m anahtar s&ouml;zc&uuml;kleri geri al',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'ba&#351;l&#305;ks&#305;z',
'info_selectionner_fichier' => '@upload@ dizininden bir dosya se&ccedil;ebilirsiniz. ',
'info_selectionner_fichier_2' => 'Bir dosya se&ccedil;&nbsp;:',
'info_signature_supprimee' => '&#304;mza silinmi&#351;',
'info_signature_supprimee_erreur' => 'Hata&nbsp;: bu silme kodu hi&ccedil;bir imzaya kar&#351;&#305; d&uuml;&#351;m&uuml;yor',
'info_site_attente' => 'Onaylanmay&#305; bekleyen Web sitesi',
'info_site_reference' => 'At&#305;fta bulunulan &ccedil;evrimi&ccedil;i site',
'info_site_refuse' => 'Web sitesi reddedildi',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Bir siteye at&#305;fta bulun',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'Bu etiketi sil',
'info_symbole_bleu' => '<b>Mavi</b> sembol bir <b>hat&#305;rlatmay&#305;</b> g&ouml;sterir : yani, ki&#351;isel kullan&#305;m&#305;n&#305;z i&ccedil;in bir iletidir.',
'info_symbole_jaune' => '<b>Sar&#305;</b> sembol <b>t&uuml;m edit&ouml;rlere y&ouml;nelik</b> bir duyuruyu g&ouml;sterir&nbsp;: t&uuml;m y&ouml;neticiler taraf&#305;ndan de&#287;i&#351;tirilebilir ve t&uuml;m edit&ouml;rler taraf&#305;ndan g&ouml;r&uuml;lebilir. ',
'info_symbole_vert' => 'Sar&#305; sembol sitenin ba&#351;ka kullan&#305;c&#305;lar&#305;yla yap&#305;lan ileti al&#305;&#351;veri&#351;lerini g&ouml;sterir.',
'info_syndication' => 'Payla&#351;&#305;m&nbsp;:',
'info_syndication_articles' => 'Makale',
'info_telecharger' => 'Bilgisayar&#305;n&#305;zdan indiriniz :',
'info_telecharger_nouveau_logo' => 'Yeni bir logo y&uuml;kle&nbsp;:',
'info_telecharger_ordinateur' => 'Bilgisayar&#305;n&#305;zdan indiriniz&nbsp;:',
'info_tous_resultats_enregistres' => '[t&uuml;m sonu&ccedil;lar kaydedildi]',
'info_tout_afficher' => 'T&uuml;m&uuml;n&uuml; g&ouml;r&uuml;nt&uuml;le',
'info_travaux_texte' => 'Bu site hen&uuml;z konfig&uuml;re edilmedi. L&uuml;tfen daha sonra u&#287;ray&#305;n&#305;z.',
'info_travaux_titre' => 'Site yap&#305;m a&#351;amas&#305;nda.',
'info_trop_resultat' => ' "@cherche_mot@" i&ccedil;in &ccedil;ok fazla sonu&ccedil; &ccedil;&#305;kt&#305;; l&uuml;tfen aramay&#305; netle&#351;tirin.',
'info_utilisation_messagerie_interne' => 'Bu sitenin i&ccedil; ileti sistemini kullan&#305;yorsunuz.',
'info_valider_lien' => 'Bu ba&#287;lant&#305;y&#305; onayla',
'info_verifier_image' => 'Resimlerinizin do&#287;ru iletildi&#287;inden emin olunuz.',
'info_vignette_defaut' => 'Varsay&#305;lan ikon',
'info_vignette_personnalisee' => 'Ki&#351;iselle&#351;tirilmi&#351; etiket',
'info_visite' => 'Ziyaret :',
'info_visites' => 'Ziyaret :',
'info_vos_rendez_vous' => '&#304;lerideki randevular&#305;n&#305;z',
'info_zoom' => 'yak&#305;nla&#351;t&#305;r',
'infos_vos_pense_bete' => 'Hat&#305;rlatmalar&#305;n&#305;z', # MODIF
'item_breve_proposee' => '&Ouml;nerilen k&#305;sa haber',

// L
'lien_afficher_icones_seuls' => 'Sadece ikonlar&#305; g&ouml;r&uuml;nt&uuml;le',
'lien_afficher_texte_icones' => 'ikonlar&#305; ve metni g&ouml;r&uuml;nt&uuml;le',
'lien_afficher_texte_seul' => 'Sadece metni g&ouml;r&uuml;nt&uuml;le',
'lien_liberer' => 'Serbest b&#305;rak',
'lien_liberer_tous' => 'Bu makaleleri serbest b&#305;rak',
'lien_nouvea_pense_bete' => 'YEN&#304; HATIRLATMA',
'lien_nouveau_message' => 'YEN&#304; &#304;LET&#304;',
'lien_nouvelle_annonce' => 'YEN&#304; DUYURU',
'lien_petitions' => 'D&#304;LEK&Ccedil;E ',
'lien_popularite' => 'Pop&uuml;lerlik : @popularite@%',
'lien_racine_site' => 'S&#304;TEN&#304;N K&Ouml;K D&#304;Z&#304;N&#304;',
'lien_reessayer' => 'Tekrar dene',
'lien_repondre_message' => 'Bu iletiye yan&#305;t ver',
'lien_supprimer' => 'Sil',
'lien_tout_afficher' => 'T&uuml;m&uuml;n&uuml; g&ouml;r&uuml;nt&uuml;le',
'lien_visite_site' => 'Bu siteyi ziyaret et',
'lien_visites' => '@visites@&nbsp;ziyaret',
'lien_voir_auteur' => 'Bu yazar&#305; g&ouml;r&uuml;nt&uuml;le',
'ligne' => 'Sat&#305;r',
'login' => 'Ba&#287;lant&#305;',
'login_acces_prive' => '&Ouml;zel alana eri&#351;im',
'login_autre_identifiant' => 'Ba&#351;ka bir kullan&#305;c&#305; ismi ile ba&#287;lan',
'login_cookie_accepte' => 'L&uuml;tfen gezgininizi (en az&#305;ndan bu site i&ccedil;in) bunlar&#305; kabul edecek bi&ccedil;imde ayarlay&#305;n&#305;z.',
'login_cookie_oblige' => 'Kendinizi g&uuml;venli bir &#351;ekilde tan&#305;mlamak i&ccedil;in &ccedil;erezleri kabul etmelisiniz.',
'login_deconnexion_ok' => 'Ba&#287;lant&#305;ya son verildi.',
'login_erreur_pass' => '&#350;ifre hatas&#305;.',
'login_espace_prive' => '&Ouml;zel alan',
'login_identifiant_inconnu' => '"@login@" kullan&#305;c&#305; ismi tan&#305;nm&#305;yor.',
'login_login' => 'Kullan&#305;c&#305; ismi :',
'login_login2' => 'Kullan&#305;c&#305; ismi&nbsp;:',
'login_login_pass_incorrect' => '(Kullan&#305;c&#305; ismi veya &#351;ifre hatal&#305;.)',
'login_motpasseoublie' => '&#350;ifreyi&nbsp;unuttum',
'login_non_securise' => 'Dikkat, bu form g&uuml;venli de&#287;il.
          E&#287;er &#351;ifrenizin a&#287; &uuml;zerinde tesbit edilmesini istemiyorsan&#305;z,
          l&uuml;tfen gezgininizde Javascript\'i &ccedil;al&#305;&#351;t&#305;r&#305;n&#305;z ve ',
'login_nouvelle_tentative' => 'Yeni deneme',
'login_par_ici' => 'Kay&#305;t oldunuz... buradan devam ediniz...',
'login_pass2' => '&#350;ifre&nbsp;:',
'login_preferez_refuser' => '<b>E&#287;er &ccedil;erezleri reddetmeyi tercih ediyorsan&#305;z,</b>   ba&#351;ka (daha az g&uuml;venli) bir ba&#287;lant&#305; y&ouml;ntemi emrinizde&nbsp;:',
'login_recharger' => 'sayfay&#305; tekrar y&uuml;kle',
'login_rester_identifie' => 'Bir ka&ccedil; g&uuml;n tan&#305;mlanm&#305;&#351; olarak kalay&#305;m',
'login_retour_public' => 'Kamusal siteye d&ouml;n',
'login_retour_site' => 'Kamusal siteye d&ouml;n',
'login_retoursitepublic' => 'Kamusal&nbsp;siteye&nbsp;d&ouml;n',
'login_sans_cookiie' => '&Ccedil;erezsiz tan&#305;mlanma',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'Kay&#305;t ol',
'login_test_navigateur' => 'Gezgini dene / Tekrar ba&#287;lan',
'login_verifiez_navigateur' => '(Ancak gezginin &#351;ifrenizi belle&#287;e almad&#305;&#287;&#305;ndan emin olunuz...)',

// M
'masquer_colonne' => 'Bu s&uuml;tunu sakla',
'masquer_trad' => '&ccedil;evirileri gizle',
'module_fichiers_langues' => 'Dil dosyalar&#305;',

// N
'navigateur_pas_redirige' => 'Gezgininiz yeniden y&ouml;nlenmiyorsa, devam etmek i&ccedil;in buraya t&#305;klay&#305;n&#305;z.',
'numero' => 'Numara',

// O
'occurence' => 'Tekrarlan&#305;&#351;',
'onglet_affacer_base' => 'Veritaban&#305;n&#305; sil',
'onglet_auteur' => 'Yazar',
'onglet_contenu_site' => 'Sitenin i&ccedil;eri&#287;i',
'onglet_evolution_visite_mod' => 'Ziyaretlerin geli&#351;imi',
'onglet_fonctions_avances' => 'Geli&#351;mi&#351; i&#351;levler',
'onglet_informations_personnelles' => 'Ki&#351;isel bilgi',
'onglet_interactivite' => 'Etkile&#351;im &ouml;zelli&#287;i',
'onglet_messagerie' => '&#304;leti sistemi',
'onglet_messages_internes' => '&#304;&ccedil; iletiler',
'onglet_messages_publics' => 'Kamu iletileri',
'onglet_messages_vide' => 'Metinsiz iletiler',
'onglet_origine_visites' => 'Ziyaretlerin kayna&#287;&#305;',
'onglet_repartition_debut' => 'Ba&#351;lang&#305;&ccedil;tan beri',
'onglet_repartition_lang' => 'Dillere g&ouml;re da&#287;&#305;l&#305;m',
'onglet_repartition_rubrique' => 'B&ouml;l&uuml;mlere g&ouml;re da&#287;&#305;l&#305;m',
'onglet_save_restaur_base' => 'Veritaban&#305;n&#305; yedekle / Geri y&uuml;kle',
'onglet_vider_cache' => '&Ouml;nbelle&#287;i bo&#351;alt',

// P
'pass_choix_pass' => 'L&uuml;tfen yeni &#351;ifrenizi se&ccedil;iniz :',
'pass_erreur' => 'Hata',
'pass_erreur_acces_refuse' => '<b>Hata : </b> art&#305;k bu siteye eri&#351;iminiz yoktur.',
'pass_erreur_code_inconnu' => 'Hata : bu &#351;ifre bu siteye eri&#351;imi olan hi&ccedil; bir ziyaret&ccedil;iye uymuyor.',
'pass_erreur_non_enregistre' => 'Hata : @email_oubli@ adresi bu siteye kay&#305;tl&#305; de&#287;il. ',
'pass_erreur_non_valide' => 'Hata :  @email_oubli@ e-posta adresi ge&ccedil;erli de&#287;il !',
'pass_erreur_probleme_technique' => 'Hata : teknik bir sorundan &ouml;t&uuml;r&uuml; e-posta g&ouml;nderilemiyor.',
'pass_espace_prive_bla' => 'Bu sitenin &ouml;zel alan&#305;,
    kay&#305;tl&#305; ziyaret&ccedil;ilere a&ccedil;&#305;kt&#305;r. Kay&#305;t olduktan sonra,
    yaz&#305;lmakta olan makalelere bakabilir, makale &ouml;nerebilir 
  ve t&uuml;m forumlara kat&#305;labilirsiniz. ',
'pass_forum_bla' => 'Kay&#305;tl&#305; ziyaret&ccedil;ilere ayr&#305;lm&#305;&#351; bir foruma
     m&uuml;dahale etmek istediniz. ',
'pass_indiquez_cidessous' => 'Daha &ouml;nce kay&#305;t oldu&#287;unuz e-posta adresinizi a&#351;a&#287;&#305;ya belirtiniz.
  Tekrar eri&#351;ebilmek i&ccedil;in gereken i&#351;lemi 
  belirten 
  bir e-posta alacaks&#305;n&#305;z. ',
'pass_mail_passcookie' => '(Bu otomatik bir iletidir)

  @nom_site_spip@ (@adresse_site@)

 sitesine tekrar eri&#351;ebilmek i&ccedil;in 
 l&uuml;tfen &#351;u adrese gidiniz :

 @sendcookie@
 O zaman yeni bir &#351;ifre girebilecek
 ve tekrar siteye ba&#287;lanabileceksiniz.  ',
'pass_mot_oublie' => '&#350;ifreyi unuttum',
'pass_nouveau_enregistre' => 'Yeni &#351;ifreniz kaydedildi.',
'pass_nouveau_pass' => 'Yeni &#351;ifre',
'pass_ok' => 'OK',
'pass_oubli_mot' => '&#350;ifremi unuttum',
'pass_quitter_fenetre' => 'Bu pencereyi terk et',
'pass_rappel_login' => 'Hat&#305;rlatma : kullan&#305;c&#305; isminiz &laquo; @login@ &raquo; d&#305;r.',
'pass_recevoir_mail' => 'Siteye eri&#351;iminizi yeniden nas&#305;l kazanabilece&#287;inizi belirten bir e-posta alacaks&#305;n&#305;z. ',
'pass_retour_public' => 'Kamu sitesine d&ouml;n&uuml;&#351;',
'pass_rien_a_faire_ici' => 'Burada yap&#305;lacak bir &#351;ey yok.',
'pass_vousinscrire' => 'Bu siteye kaydolman&#305;z',
'precedent' => '&ouml;nceki',
'previsualisation' => '&Ouml;ng&ouml;r&uuml;nt&uuml;le',
'previsualiser' => '&Ouml;ng&ouml;r&uuml;nt&uuml;le',

// R
'retour' => 'Geri d&ouml;n',

// S
'spip_conforme_dtd' => 'SPIP bu belgeyi DOCTYPE\'e uygun buluyor :',
'squelette' => 'iskelet',
'squelette_inclus_ligne' => 'iskelet eklendi, sat&#305;r',
'squelette_ligne' => 'iskelet, sat&#305;r',
'stats_visites_et_popularite' => '@visites@ ziyaret; pop&uuml;lerlik : @popularite@',
'suivant' => 'sonraki',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@&nbsp;bayt',
'texte_actualite_site_1' => 'Aray&uuml;ze al&#305;&#351;&#305;nca &laquo;',
'texte_actualite_site_2' => 'T&uuml;m aray&uuml;z',
'texte_actualite_site_3' => '&raquo;\'e t&#305;klayarak daha fazla se&ccedil;ene&#287;e ula&#351;abilirsiniz.',
'texte_creation_automatique_vignette' => 'Bu sitede &ouml;ng&ouml;r&uuml;nt&uuml;leme ikonlar&#305;n&#305;n otomatik olarak yarat&#305;lmas&#305; i&#351;lemi etkinle&#351;tiri&#351;mi&#351;tir. E&#287;er bu formdan hareket ederek @gd_formats@, formatl&#305; resimler y&uuml;klerseniz, bunlara, en fazla @taille_preview@&nbsp;piksel boyutunda bir ikon e&#351;lik edecektir.',
'texte_documents_associes' => 'A&#351;a&#287;&#305;daki belgeler makale ile ba&#287;lant&#305;l&#305; olup,
    do&#287;rudan makalenin i&ccedil;ine dahil edilmemi&#351;tir. Kamu sitesinin sayfa d&uuml;zenine g&ouml;re,
    sonradan belge eki olarak g&ouml;r&uuml;lebilir.',
'texte_erreur_mise_niveau_base' => 'G&uuml;ncelleme s&#305;ras&#305;nda veritaban&#305; hatas&#305;. @fichier@ resmi ula&#351;mad&#305; (@id_article@ makalesi). Bu referans&#305; kaydedip g&uuml;ncelemeyi tekrar deneyiniz ve resimlerin makalelerde g&ouml;r&uuml;ld&uuml;&#287;&uuml;nden emin olunuz. ',
'texte_erreur_visiteur' => '&Ouml;zel alana, giri&#351;e izin vermeyen bir kullan&#305;c&#305; ismiyle eri&#351;meyi denediniz.',
'texte_inc_auth_1' => '<b>@auth_login@</b> kullan&#305;c&#305; ismini girdiniz ancak veritaban&#305;nda bu kullan&#305;c&#305; ismi yok/art&#305;k yok. L&uuml;tfen &#351;unu deneyiniz',
'texte_inc_auth_2' => 'gezgininizi kapat&#305;p tekrar &ccedil;al&#305;&#351;t&#305;r&#305;n&#305;z ve ',
'texte_inc_auth_3' => 'tekrar ba&#287;lan&#305;n&#305;z.',
'texte_inc_config' => 'Bu sayfalarda yap&#305;lan de&#287;i&#351;iklikler sitenizin i&#351;leyi&#351;i &uuml;zerinde b&uuml;y&uuml;k &ouml;l&ccedil;&uuml;de etkilidir. SPIP sisteminin i&#351;leyi&#351;ine a&#351;ina olmad&#305;&#287;&#305;n&#305;z s&uuml;rece m&uuml;dahale etmemenizi &ouml;neririz.  <br /><br /><b>Daha genel bir ifadeyle s&ouml;ylemek gerekirse bu sayfalarla ilgilenme i&#351;ini sitenin A&#287; Y&ouml;neticisi\'ne b&#305;rakman&#305;z&#305; &ouml;zellikle &ouml;neririz.</b>',
'texte_inc_meta_1' => 'Sistem <code>@fichier@</code> dosyas&#305;n&#305;n yaz&#305;lmas&#305; s&#305;ras&#305;nda bir hata ile kar&#351;&#305;la&#351;t&#305;. L&uuml;tfen, site y&ouml;neticisi olarak ',
'texte_inc_meta_2' => '(<code>ecrire/data/</code> dizinindeki) ',
'texte_inc_meta_3' => '<code>@repertoire@</code> dizinindeki yazma haklar&#305;n&#305; kontrol ediniz. ',
'texte_statut_en_cours_redaction' => 'Yaz&#305;l&#305;yor',
'texte_statut_poubelle' => '&Ccedil;&ouml;pe at&#305;ld&#305;',
'texte_statut_propose_evaluation' => 'De&#287;erlendirmeye al&#305;nd&#305;',
'texte_statut_publie' => '&Ccedil;evrimi&ccedil;i yay&#305;nland&#305;',
'texte_statut_refuse' => 'Reddedildi',
'titre_ajouter_mot_cle' => 'B&#304;R ANAHTAR-S&Ouml;ZC&Uuml;K EKLE :',
'titre_breve_proposee' => '&Ouml;nerilen k&#305;sa haber',
'titre_breve_publiee' => 'Yay&#305;nlanan k&#305;sa haber',
'titre_breve_refusee' => 'Reddedilen k&#305;sa haber',
'titre_cadre_raccourcis' => 'KISA YOLLAR :',
'titre_changer_couleur_interface' => 'Aray&uuml;z rengini de&#287;i&#351;tir',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Bu makaleyi y&ouml;netebilirsiniz',
'titre_image_administrateur' => 'Y&ouml;netici',
'titre_image_aide' => 'Bu eleman hakk&#305;nda yard&#305;m',
'titre_image_auteur_supprime' => 'Silinmi&#351; yazar',
'titre_image_redacteur' => 'Eri&#351;im hakk&#305; olmayan yazar',
'titre_image_redacteur_02' => 'Yazar',
'titre_image_visiteur' => 'Ziyaret&ccedil;i',
'titre_joindre_document' => 'B&#304;R BELGE EKLE',
'titre_liens_entrants' => 'Giren ba&#287;lant&#305;lar',
'titre_mots_cles' => 'ANAHTAR S&Ouml;ZC&Uuml;KLER',
'titre_probleme_technique' => 'Dikkat&nbsp;: teknik bir sorun (SQL hizmet birimi) sitenin bu b&ouml;l&uuml;m&uuml;ne eri&#351;imi engelliyor. Anlay&#305;&#351;&#305;n&#305;z i&ccedil;in te&#351;ekk&uuml;rler.',
'titre_publier_document' => 'BU B&Ouml;L&Uuml;M ALTINDA B&#304;R BELGE YAYINLA',
'titre_signatures_attente' => 'Onay bekleyen imzalar',
'titre_signatures_confirmees' => 'Onaylanm&#305;&#351; imzalar',
'titre_statistiques' => 'Site istatistikleri',
'titre_titre_document' => 'Belge ba&#351;l&#305;&#287;&#305;&nbsp;:',
'todo' => 'gelecek',
'trad_reference' => '(referans makale)',

// Z
'zbug_balise_b_aval' => '&nbsp;: B etiketinde sorun var',
'zbug_balise_inexistante' => 'hata @from@: #@balise@ komutu mevcut de&#287;il', # MODIF
'zbug_balise_sans_argument' => '@balise@ komutunda arg&uuml;man eksik',
'zbug_boucle' => 'd&ouml;ng&uuml;',
'zbug_boucle_recursive_undef' => 'tan&#305;ms&#305;z tekrarl&#305; d&ouml;ng&uuml;', # MODIF
'zbug_calcul' => 'hesaplama',
'zbug_champ_hors_boucle' => '@champ@ alan&#305; d&ouml;ng&uuml; d&#305;&#351;&#305;nda',
'zbug_champ_hors_motif' => '@champ@ alan&#305; @motif@ d&ouml;ng&uuml;s&uuml; d&#305;&#351;&#305;nda ', # MODIF
'zbug_code' => 'kod',
'zbug_critere_inconnu' => 'tan&#305;ms&#305;z kriter @critere@', # MODIF
'zbug_distant_interdit' => 'yasaklanm&#305;&#351; d&#305;&#351; veri dosyas&#305;', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'endekssiz bir tabloda tekrarlar var', # MODIF
'zbug_doublon_table_sans_index' => 'endekslenmemi&#351; bir tabloda tekrarlanan bilgiler', # MODIF
'zbug_erreur_boucle_double' => 'D&Ouml;NG&Uuml;@id@: &ccedil;ift tan&#305;ml&#305;', # MODIF
'zbug_erreur_boucle_fermant' => 'D&Ouml;NG&Uuml;@id@: kapatma etiketi eksik', # MODIF
'zbug_erreur_boucle_syntaxe' => 'D&ouml;ng&uuml; t&uuml;mcesi hatal&#305;', # MODIF
'zbug_erreur_compilation' => 'derleme hatas&#305;',
'zbug_erreur_execution_page' => 'sayfa i&#351;letilirken hata olu&#351;tu', # MODIF
'zbug_erreur_filtre' => 'Hata : <b>&laquo; @filtre@ &raquo;</b> filtresi tan&#305;ms&#305;z', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} sadece (FORUMS) veya  (RUBRIQUES) i&ccedil;in uygulanabilir', # MODIF
'zbug_erreur_squelette' => '&#304;skelette hata var',
'zbug_hors_compilation' => 'Derleme D&#305;&#351;&#305;',
'zbug_info_erreur_squelette' => 'Sitede hata var',
'zbug_inversion_ordre_inexistant' => 'olmayan bir s&#305;ralama ters &ccedil;evrilemez', # MODIF
'zbug_pagination_sans_critere' => 'kritersiz veya kendini &ccedil;a&#287;&#305;ran d&ouml;ng&uuml;de kullan&#305;lan #PAGINATION {pagination} ', # MODIF
'zbug_parametres_inclus_incorrects' => 'Ekleme parametreleri hatal&#305;', # MODIF
'zbug_profile' => 'Hesaplama s&uuml;resi&nbsp;: @time@',
'zbug_resultat' => 'sonu&ccedil;',
'zbug_serveur_indefini' => 'SQL hizmet birimi tan&#305;ms&#305;z', # MODIF
'zbug_statistiques' => 'S&uuml;reye g&ouml;re s&#305;n&#305;flanm&#305;&#351; SQL istekleri istatistikleri',
'zbug_table_inconnue' => '&laquo; @table@ &raquo; SQL tablosu tan&#305;ms&#305;z',
'zxml_connus_attributs' => 'bilinen &ouml;znitelikler',
'zxml_de' => 'n&#305;n / nin',
'zxml_inconnu_attribut' => 'bilinmeyen &ouml;znitelik',
'zxml_inconnu_balise' => 'bilinmeyen etiket',
'zxml_inconnu_entite' => 'bilinmeyen madde',
'zxml_inconnu_id' => 'bilinmeyen ID',
'zxml_mais_de' => 'ama n&#305;n / nin',
'zxml_non_conforme' => 'amaca uygun de&#287;il',
'zxml_non_fils' => 'bir alt maddesi de&#287;il',
'zxml_nonvide_balise' => 'bo&#351; olmayan etiket',
'zxml_obligatoire_attribut' => 'zorunlu ama belirtilmemi&#351; etiket',
'zxml_succession_fils_incorrecte' => 'alt maddelerin pe&#351;pe&#351;e gelmesi hatal&#305;',
'zxml_survoler' => 'do&#287;rular&#305; g&ouml;rmek i&ccedil;in &uuml;zerindne ge&ccedil;mek ???',
'zxml_valeur_attribut' => '&ouml;zniteli&#287;in de&#287;eri',
'zxml_vide_balise' => 'bo&#351; etiket',
'zxml_vu' => '&ouml;nceden g&ouml;r&uuml;len'
);

?>
